<?PHP
/**
 * Constains lists for categorizing links between objects and tags.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Constains lists for categorizing links between objects and tags.
 */
final class MDConcObjectTagRelTypes implements MDImporterConcordanceListInterface {

    private const RELATION_TYPE_NAMES = [

        '' => 'tag',
        'tag' => 'tag',
        'schlagwort' => 'tag',
        'Motivgattung' => 'tag',
        'motivgattung' => 'tag',
        'Assoziation' => 'tag',
        'assoziation' => 'tag',
        'description' => 'tag',
        'emotion' => 'tag',
        'atmosphäre' => 'tag',
        'schlagwort hist.ereignis' => 'tag',
        'schlagwort thema' => 'tag',

        "motive" => "display_subject",
        "motiv" => "display_subject",
        "display" => "display_subject",
        "Bildelement" => "display_subject",

        "material" => "material",

        "technique" => "technique",
        "technik" => "technique",

    ];

    // Maps to event type
    private const RELATION_TYPES_MAPPED_TO_EVENTS = [
        '\'datierung\'' => ['event_type' => 24, 'target_section' => 'time'],
        'datierung' => ['event_type' => 24, 'target_section' => 'time'],
        'schlagwort zeitraum' => ['event_type' => 24, 'target_section' => 'time'],
    ];

    /**
     * Returns the mapped event type and event type target
     * of a supposed tag-object relationship name.
     *
     * @param string $input Input string (relation type name).
     *
     * @return array{event_type: int, target_section: 'time'|'actor'|'place'}
     */
    public static function getMappedEventType(string $input):array {

        if (isset(self::RELATION_TYPES_MAPPED_TO_EVENTS[strtolower($input)])) {
            return self::RELATION_TYPES_MAPPED_TO_EVENTS[strtolower($input)];
        }

        throw new MDImporterMissingConcordance("Unknown object-tag relationship type: " . $input);

    }

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (isset(self::RELATION_TYPE_NAMES[$input])) {
            return self::RELATION_TYPE_NAMES[$input];
        }
        if (isset(self::RELATION_TYPE_NAMES[strtolower($input)])) {
            return self::RELATION_TYPE_NAMES[strtolower($input)];
        }

        if (isset(self::RELATION_TYPES_MAPPED_TO_EVENTS[strtolower($input)])) {
            throw new MDImporterTagRelationTypeIsEventType("Tag-object relationship type is signifies not tags, but an event component.");
        }

        throw new MDImporterMissingConcordance("Unknown object-tag relationship type: " . $input);

    }
}
